/*
 * This file is part of accounts-ui
 *
 * Copyright (C) 2010 Nokia Corporation.
 *
 * Contact: Alberto Mardegan <alberto.mardegan@nokia.com>
 *
 * This software, including documentation, is protected by copyright controlled
 * by Nokia Corporation. All rights are reserved.
 * Copying, including reproducing, storing, adapting or translating, any or all
 * of this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef ACCOUNTSUI_N_CLIENT_H
#define ACCOUNTSUI_N_CLIENT_H

#include <AccountsUI/namespaced-accountsui.h>

namespace AccountsUI {

class NClientPrivate;

/*!
 * @class NClient
 * @headerfile AccountsUI/n-client.h \
 * AccountsUI/NClient
 * @brief Proxy class for the Accounts UI application.
 *
 * @details Applications can use the NClient object to invoke the Accounts UI
 * application.
 */
class NClient: public AccountsUI
{
    Q_OBJECT

public:
    NClient(QObject *parent = 0);
    virtual ~NClient();

    /*!
     * Starts the accounts UI.
     * @param serviceType This is a hint to highlight the content more
     * relevant fot the given service type.
     */
    void launch(const QString &serviceType = QString());

    /*!
     * Starts the accounts UI on the provider selection page, to invite the
     * user to create an account for the given service type. If callbackTitle
     * and callbackService are give, an additional button will be shown on the
     * last page of the successful account creation: the label will be defined
     * by callbackTitle, and when the button will be clicked the service
     * callbackService will be activated using the MeegoTouch service FW.
     * @param serviceType The type of service we want to create accounts for.
     * @param callbackTitle The label for the action button.
     * @param callbackService The service name of the service to be activated.
     */
    void createAccount(const QString &serviceType,
                       const QString &callbackTitle = QString(),
                       const QString &callbackService = QString());

private:
    NClientPrivate *d_ptr;
    Q_DECLARE_PRIVATE(NClient)
};

} // namespace

#endif // ACCOUNTSUI_N_CLIENT_H
