/*
 * This file is part of accounts-ui
 *
 * Copyright (C) 2009-2010 Nokia Corporation.
 *
 * Contact: Alberto Mardegan <alberto.mardegan@nokia.com>
 *
 * This software, including documentation, is protected by copyright controlled
 * by Nokia Corporation. All rights are reserved.
 * Copying, including reproducing, storing, adapting or translating, any or all
 * of this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef ACCOUNTSUI_N_PROVIDER_PLUGIN_PROCESS_H
#define ACCOUNTSUI_N_PROVIDER_PLUGIN_PROCESS_H

#include <AccountsUI/ProviderPluginProcess>

namespace AccountsUI {

class NProviderPluginProcessPrivate;

/*!
 * @class NProviderPluginProcess
 * @headerfile AccountsUI/n-provider-plugin-process.h \
 * AccountsUI/NProviderPluginProcess
 * @brief Class to manage the account provider plugins as separate processes.
 *
 * @details The NProviderPluginProcess class takes care of handling the
 * communication protocol between the account plugin process and the accounts
 * UI.
 */
class ACCOUNTSUI_EXPORT NProviderPluginProcess :
    public ProviderPluginProcess
{
    Q_OBJECT

public:
    NProviderPluginProcess(int &argc, char **argv);
    virtual ~NProviderPluginProcess();

    // ProviderPluginProcess
    AbstractAccountSetupContext *accountSetupContext(Accounts::Account *account,
                                                     SetupType type,
                                                     QObject *parent = 0);
    MApplicationPage *mainPage();

private:
    NProviderPluginProcessPrivate *d_ptr;
    Q_DECLARE_PRIVATE(NProviderPluginProcess)
};

} // namespace

#endif // ACCOUNTSUI_N_PROVIDER_PLUGIN_PROCESS_H
